aboutsummaryrefslogtreecommitdiff
path: root/engines/wintermute/graphics/transparent_surface.cpp
diff options
context:
space:
mode:
authorJohannes Schickel2013-08-03 02:44:47 +0200
committerJohannes Schickel2013-08-03 04:02:53 +0200
commit0ee407c44bc8ce3c1c26ba68d5eb5a68599788c7 (patch)
tree484a725328b1f98c48b583426202f4ecdbc5f7d6 /engines/wintermute/graphics/transparent_surface.cpp
parent431841073185d45a945a459768fccc091cc2c2fd (diff)
downloadscummvm-rg350-0ee407c44bc8ce3c1c26ba68d5eb5a68599788c7.tar.gz
scummvm-rg350-0ee407c44bc8ce3c1c26ba68d5eb5a68599788c7.tar.bz2
scummvm-rg350-0ee407c44bc8ce3c1c26ba68d5eb5a68599788c7.zip
WINTERMUTE: Take advantage of Surface::getPixels.
Diffstat (limited to 'engines/wintermute/graphics/transparent_surface.cpp')
-rw-r--r--engines/wintermute/graphics/transparent_surface.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/engines/wintermute/graphics/transparent_surface.cpp b/engines/wintermute/graphics/transparent_surface.cpp
index 9efeea9cad..faaa3b138c 100644
--- a/engines/wintermute/graphics/transparent_surface.cpp
+++ b/engines/wintermute/graphics/transparent_surface.cpp
@@ -160,8 +160,8 @@ TransparentSurface::TransparentSurface(const Surface &surf, bool copyData) : Sur
format = surf.format;
// We need to cast the const qualifier away here because 'pixels'
// always needs to be writable. 'surf' however is a constant Surface,
- // thus getBasePtr will always return const pixel data.
- pixels = const_cast<void *>(surf.getBasePtr(0, 0));
+ // thus getPixels will always return const pixel data.
+ pixels = const_cast<void *>(surf.getPixels());
}
}
@@ -339,7 +339,7 @@ Common::Rect TransparentSurface::blit(Graphics::Surface &target, int posX, int p
if ((width != srcImage.w) || (height != srcImage.h)) {
// Scale the image
img = imgScaled = srcImage.scale(width, height);
- savedPixels = (byte *)img->getBasePtr(0, 0);
+ savedPixels = (byte *)img->getPixels();
} else {
img = &srcImage;
}